@@ -5,10 +5,14 @@ use parent 'Config::Tiny';
 
 # Bare-bones hack to wrap Config::Tiny
 
+# TODO: Use an exobrain.config.d/ or similar multi-file structure.
+
 sub new {
     my ($class) = @_;
 
-    my $self = $class->read("$ENV{HOME}/.exobrainrc");
+    my $file = $ENV{EXOBRAIN_CONFIG} || "$ENV{HOME}/.exobrainrc";
+
+    my $self = $class->read($file);
 
     $self or die "Cannot read config - " . Config::Tiny->errstr;
 
@@ -27,7 +31,7 @@ Exobrain::Config
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 AUTHOR
 
@@ -35,7 +39,7 @@ Paul Fenwick <pjf@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Paul Fenwick.
+This software is copyright (c) 2014 by Paul Fenwick.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
