@@ -1,8 +1,6 @@
 package Exobrain::Message::Raw;
 use v5.10.0;
 use Moose;
-use ZMQ::Constants qw(ZMQ_SNDMORE);
-use ZMQ::LibZMQ2;
 use JSON::Any;
 use Method::Signatures;
 use Carp;
@@ -86,7 +84,7 @@ Exobrain::Message::Raw
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =for Pod::Coverage BUILD
 
@@ -96,7 +94,7 @@ Paul Fenwick <pjf@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Paul Fenwick.
+This software is copyright (c) 2014 by Paul Fenwick.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
